@@ -1321,10 +1321,10 @@ writeListValue (CCSSetting *setting,
 	break;
     case TypeFloat:
 	{
-	    float *item;
+	    gdouble *item;
 	    while (list)
 	    {
-		item = malloc (sizeof (float));
+		item = malloc (sizeof (gdouble));
 		if (item)
 		{
 		    *item = list->data->value.asFloat;
@@ -1577,7 +1577,7 @@ writeIntegratedOption (CCSContext *context,
 		if (!ccsGetBool (setting, &clickToFocus))
 		    break;
 
-		newValue = clickToFocus ? "click" : "mouse";
+		newValue = clickToFocus ? "click" : "sloppy";
 		currentValue = gconf_client_get_string (client,
 							optionName, &err);
 
